@@ -2,10 +2,9 @@
 
 import inspect
 import logging
-import sys
 from typing import Dict, Tuple
 
-from . import filters, helpers, state
+from . import state
 
 
 def create_logger_record(
@@ -17,8 +16,6 @@ def create_logger_record(
     if parent_name in state.silenced:
         return False
 
-    ensure_initialized()
-
     logger = get_logger(name, parent_name)
     if not logger.isEnabledFor(level):
         return False
@@ -26,7 +23,7 @@ def create_logger_record(
     record = logger.makeRecord(
         name,
         level,
-        fn=frame.f_globals['__file__'],
+        fn=parse_fn(frame.f_globals),
         lno=frame.f_lineno,
         msg=message,
         args=args,
@@ -38,6 +35,10 @@ def create_logger_record(
     return True
 
 
+def parse_fn(frame_info: Dict) -> str:
+    return frame_info.get('__file__', 'interactive')
+
+
 def parse_name(custom_name: str, frame_info: Dict) -> Tuple[str, str]:
     module_name = custom_name or frame_info['__name__']
     if module_name == '__main__':
@@ -49,14 +50,6 @@ def parse_name(custom_name: str, frame_info: Dict) -> Tuple[str, str]:
     return module_name, parent_module_name
 
 
-def ensure_initialized():
-    if not state.initialized:
-        if 'pytest' in sys.modules:
-            filters.install(logging.root)
-        else:  # pragma: no cover
-            helpers.init()
-
-
 def get_logger(name: str, parent_name: str):
     logger = logging.getLogger(name)
     if not logger.level:
